@@ -120,28 +120,29 @@ class RadialDistributionFunction(MDObservable):
         self.nbin = nbin
         self.pbc = pbc
 
-    def _global_configure(self):
-        """Define parameters needed for the calculation of g(r)."""
-        super()._global_configure()
+        # the width of the bar in the histogram
+        self.dgofr_ = self.rmax / self.nbin
 
+    def _local_configure(self, frame):
+        """Configure the Radial Distribution Function calculus.
+
+        It receive a frame and define the boundary conditions, initializate the
+        volumen, the counter and the ctypes requirements.
+        """
         # pbc = True -> 1; False -> 0 in C code
         self.pbc = 1 if self.pbc else 0
 
         # init volume
         self.volume_ = 0.0
 
-        # parameters of the g(r), the counter and the distance between
-        # points in the histogram
+        # g(r) the counter
         self.ngofr_ = 0
-        self.dgofr_ = self.rmax / self.nbin
-
-    def _local_configure(self, frame):
-        """To calculate natoms and ctypes requires."""
-        types = frame.types
 
         # calculate natoms_c_ and natoms_i_
-        self.natoms_c_ = np.count_nonzero(types == self.type_c)
-        self.natoms_i_ = np.count_nonzero(types == self.type_i)
+        self.mask_c_ = frame._mask_type(self.type_c)
+        self.mask_i_ = frame._mask_type(self.type_i)
+        self.natoms_c_ = frame._natoms_type(self.mask_c_)
+        self.natoms_i_ = frame._natoms_type(self.mask_i_)
 
         # ctypes requirements to interact with C code
         lib_rdf = ct.CDLL(
@@ -168,11 +169,16 @@ class RadialDistributionFunction(MDObservable):
         box = frame.box
         self.volume_ += np.prod(box)
 
-        mask_c = frame.types == self.type_c
-        mask_i = frame.types == self.type_i
-
-        xc, yc, zc = frame.x[mask_c], frame.y[mask_c], frame.z[mask_c]
-        xi, yi, zi = frame.x[mask_i], frame.y[mask_i], frame.z[mask_i]
+        xc, yc, zc = (
+            frame.x[self.mask_c_],
+            frame.y[self.mask_c_],
+            frame.z[self.mask_c_],
+        )
+        xi, yi, zi = (
+            frame.x[self.mask_i_],
+            frame.y[self.mask_i_],
+            frame.z[self.mask_i_],
+        )
 
         # accomodate the data type of pointers to C code
         box = np.asarray(box, dtype=np.float32)
